@@ -12,7 +12,8 @@ urlpatterns = patterns('',
     url(r'^$',
         views.list_flashcards,
         name = 'list_flashcards'),
-    url(r'^practice/$',
+    # FIXME: Make passing a string optional
+    url(r'^practice/(\s+)/$',
         views.practice_flashcards,
         name = 'practice_flashcards'),
     url(r'^rating/$',
